=== modified file 'plugin/rabbitmq/rabbitmq_log.cc'
--- plugin/rabbitmq/rabbitmq_log.cc	2010-04-07 01:08:35 +0000
+++ plugin/rabbitmq/rabbitmq_log.cc	2010-04-07 01:45:18 +0000
@@ -76,6 +76,14 @@
  */
 static bool sysvar_rabbitmq_log_enabled= false;
 
+/**
+ * The name of the replicator plugin
+ * to pair the rabbitmq log's applier with.
+ * Defaults to "default"
+ */
+static char *sysvar_rabbitmq_use_replicator= NULL;
+static const char DEFAULT_USE_REPLICATOR[]= "default";
+
 
 RabbitMQLog::RabbitMQLog(const string name_arg, 
 			 RabbitMQHandler* mqHandler)
@@ -88,7 +96,8 @@
 {
 }
 
-void RabbitMQLog::apply(const message::Transaction &to_apply)
+plugin::ReplicationReturnCode
+RabbitMQLog::apply(Session &, const message::Transaction &to_apply)
 {
   size_t message_byte_length= to_apply.ByteSize();
   uint8_t* buffer= static_cast<uint8_t *>(malloc(message_byte_length));
@@ -96,7 +105,7 @@
   {
     errmsg_printf(ERRMSG_LVL_ERROR, _("Failed to allocate enough memory to transaction message\n"));
     deactivate();
-    return;
+    return plugin::UNKNOWN_ERROR;
   }
 
   to_apply.SerializeWithCachedSizesToArray(buffer);
@@ -111,8 +120,10 @@
   {
     errmsg_printf(ERRMSG_LVL_ERROR, _(e.what()));
     deactivate();
+    return plugin::UNKNOWN_ERROR;
   }
   free(buffer);
+  return plugin::SUCCESS;
 }
 
 static RabbitMQLog *rabbitmqLogger; ///< the actual plugin
@@ -143,7 +154,7 @@
     }
     try 
     {
-      rabbitmqLogger= new RabbitMQLog("rabbit-log", rabbitmqHandler);
+      rabbitmqLogger= new RabbitMQLog("rabbit_log_applier", rabbitmqHandler);
     } 
     catch (exception& e) 
     {
@@ -153,6 +164,9 @@
     }
 
     context.add(rabbitmqLogger);
+    ReplicationServices &replication_services= ReplicationServices::singleton();
+    string replicator_name(sysvar_rabbitmq_use_replicator);
+    replication_services.attachApplier(rabbitmqLogger, replicator_name);
     return 0;
   }
   return 0;
@@ -228,6 +242,13 @@
                           NULL, /* update func*/
                           "ReplicationRoutingKey" /* default */);
 
+static DRIZZLE_SYSVAR_STR(use_replicator,
+                          sysvar_rabbitmq_use_replicator,
+                          PLUGIN_VAR_READONLY,
+                          N_("Name of the replicator plugin to use (default='default_replicator')"),
+                          NULL, /* check func */
+                          NULL, /* update func*/
+                          DEFAULT_USE_REPLICATOR /* default */);
 
 static drizzle_sys_var* system_variables[]= {
   DRIZZLE_SYSVAR(enable),
@@ -238,6 +259,7 @@
   DRIZZLE_SYSVAR(virtualhost),
   DRIZZLE_SYSVAR(exchange),
   DRIZZLE_SYSVAR(routingkey),
+  DRIZZLE_SYSVAR(use_replicator),
   NULL
 };
 

=== modified file 'plugin/rabbitmq/rabbitmq_log.h'
--- plugin/rabbitmq/rabbitmq_log.h	2010-04-04 07:54:04 +0000
+++ plugin/rabbitmq/rabbitmq_log.h	2010-04-07 01:45:18 +0000
@@ -69,7 +69,8 @@
    *
    * @param[in] to_apply the transaction to send
    */
-  void apply(const drizzled::message::Transaction &to_apply);
+  drizzled::plugin::ReplicationReturnCode
+  apply(drizzled::Session &session, const drizzled::message::Transaction &to_apply);
 
 };
 

=== modified file 'plugin/rabbitmq/tests/r/variables.result'
--- plugin/rabbitmq/tests/r/variables.result	2010-04-07 01:08:35 +0000
+++ plugin/rabbitmq/tests/r/variables.result	2010-04-07 01:45:18 +0000
@@ -3,3 +3,7 @@
 rabbitmq	0.1	Marcus Eriksson	FALSE	rabbitmq	RabbitMQ Replicator	GPL
 SELECT * FROM data_dictionary.plugins WHERE module_name = 'rabbitmq';
 PLUGIN_NAME	PLUGIN_TYPE	IS_ACTIVE	MODULE_NAME
+rabbit_log_applier	TransactionApplier	TRUE	rabbitmq
+SELECT * FROM data_dictionary.replication_streams;
+REPLICATOR	APPLIER
+default_replicator	rabbit_log_applier

=== modified file 'plugin/rabbitmq/tests/t/variables-master.opt'
--- plugin/rabbitmq/tests/t/variables-master.opt	2010-04-07 01:08:35 +0000
+++ plugin/rabbitmq/tests/t/variables-master.opt	2010-04-07 01:45:18 +0000
@@ -1,1 +1,1 @@
---plugin-add=rabbitmq --rabbitmq-host=serialcoder --rabbitmq-username=guest --rabbitmq-password=guest
+--plugin-add=rabbitmq --rabbitmq-enable --rabbitmq-host=serialcoder --rabbitmq-username=guest --rabbitmq-password=guest

=== modified file 'plugin/rabbitmq/tests/t/variables.test'
--- plugin/rabbitmq/tests/t/variables.test	2010-04-07 01:08:35 +0000
+++ plugin/rabbitmq/tests/t/variables.test	2010-04-07 01:45:18 +0000
@@ -1,2 +1,3 @@
 SELECT * FROM data_dictionary.modules WHERE module_name = 'rabbitmq';
 SELECT * FROM data_dictionary.plugins WHERE module_name = 'rabbitmq';
+SELECT * FROM data_dictionary.replication_streams;

